Atmosphyre Documentation
===================================

**Atmosphyre** is a Python package to characterise the impact of atmospheric dispersion on a spectrograph's transmission.

It can be installed with pip:

.. code-block:: console

   (.venv) $ pip install astrophyre

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   introduction
   functions
   examples
